Mannequin Challenge des médiathèques de Val Parisis Agglo

Val Parisis Agglo

Mannequin Challenge des médiathèques de Val Parisis Agglo

Le réseau des médiathèques de la Communauté d'agglomération Val Parisis (95) : entre lieu d’étude, de découverte et de vie et de partage !
Retrouvez toutes les informations sur http://bit.ly/2ipFLNd
Musique : Itro – Panda
Lien : https://www.youtube.com/watch?v=FkKjZz2vpy4
Facebook : https://www.facebook.com/officialitro/?fref=ts

03/01/2017